#!/bin/bash

# IMPORTANT: mh=[M/H] i.e. log10(M/H)

options=("<atlas9>" "teff" "logg" "mh" "vturb" "path_to_atlas_files")

if [ $# -ne ${#options[*]} ]; then
  echo "Usage: `basename $0` ${options[*]}"
  exit 1
fi

atlas9=$1
teff=$2
logg=$3
mh=$4
vturb=$5
path_to_atlas_files=$6

mhstr=`echo "${mh}*10" | bc`
mhstr=`echo ${mhstr} | awk ' { if($1>=0) { print $1} else {print $1*-1 }}'`
mhstr=`printf "%02.0f" ${mhstr}`
prefix_mh=`echo ${mh} | awk '{ if($1>=0) {printf("%s","p")} else {printf("%s","m")}}'`

vturbstr=`printf "%2i" ${vturb}`
vturbstr=`echo ${vturbstr} | tr -d ' '`

kappros_file=${path_to_atlas_files}/kap${prefix_mh}${mhstr}.ros
odf_file=${path_to_atlas_files}/${prefix_mh}${mhstr}big${vturbstr}.bdf
molecules_file=${path_to_atlas_files}/molecules.dat
echo ${kappros_file}
echo $odf_file

mint_mol=6500
if [ "${teff}" -ge "${mint_mol}" ]; then
  mol_switch=OFF
else
  mol_switch=ON
fi

rm -f fort.*

#Opacity and ODF file calls
ln -sf  ${kappros_file} fort.1
#ln -sf kapP10.ros fort.1
ln -sf  ${odf_file} fort.9
#ln -sf P10bigvt04.bdf fort.9
ln -sf  ${molecules_file} fort.2

#Starting model assignation
#ln -sf wasp12.a9 fort.3
vturb=`echo ${vturb}*100000 | bc`
#vturb=`printf "   %3.1E" $vturb`

# transfrom [M/H] to absolute abundance scale
mh=`echo "e(${mh}*l(10.))" | bc -l`

#Atlas is called and fed with his input control cards
./${atlas9} <<EOF
READ KAPPA
MOLECULES ${mol_switch}
READ MOLECULES
FREQUENCIES 337 1 337 BIG
TEFF ${teff}
GRAVITY ${logg}
TITLE atlas9 model
CALCULATE 72 -6.875 0.125
OPACITY IFOP 1 1 1 1 1 1 1 1 1 1 1 1 1 0 1 0 0 0 0 0
CONVECTION ON MIXLTH 1.25
VTURB ${vturb}
ABUNDANCE SCALE ${mh}
ABUNDANCE CHANGE 1 0.92040 2 0.07834
 ABUNDANCE CHANGE  3 -10.94  4 -10.64  5  -9.49  6  -3.52  7  -4.12  8  -3.21
 ABUNDANCE CHANGE  9  -7.48 10  -3.96 11  -5.71 12  -4.46 13  -5.57 14  -4.49
 ABUNDANCE CHANGE 15  -6.59 16  -4.71 17  -6.54 18  -5.64 19  -6.92 20  -5.68
 ABUNDANCE CHANGE 21  -8.87 22  -7.02 23  -8.04 24  -6.37 25  -6.65 26  -4.54
 ABUNDANCE CHANGE 27  -7.12 28  -5.79 29  -7.83 30  -7.44 31  -9.16 32  -8.63
 ABUNDANCE CHANGE 33  -9.67 34  -8.63 35  -9.41 36  -8.73 37  -9.44 38  -9.07
 ABUNDANCE CHANGE 39  -9.80 40  -9.44 41 -10.62 42 -10.12 43 -20.00 44 -10.20
 ABUNDANCE CHANGE 45 -10.92 46 -10.35 47 -11.10 48 -10.27 49 -10.38 50 -10.04
 ABUNDANCE CHANGE 51 -11.04 52  -9.80 53 -10.53 54  -9.87 55 -10.91 56  -9.91
 ABUNDANCE CHANGE 57 -10.87 58 -10.46 59 -11.33 60 -10.54 61 -20.00 62 -11.03
 ABUNDANCE CHANGE 63 -11.53 64 -10.92 65 -11.69 66 -10.90 67 -11.78 68 -11.11
 ABUNDANCE CHANGE 69 -12.04 70 -10.96 71 -11.98 72 -11.16 73 -12.17 74 -10.93
 ABUNDANCE CHANGE 75 -11.76 76 -10.59 77 -10.69 78 -10.24 79 -11.03 80 -10.91
 ABUNDANCE CHANGE 81 -11.14 82 -10.09 83 -11.33 84 -20.00 85 -20.00 86 -20.00
 ABUNDANCE CHANGE 87 -20.00 88 -20.00 89 -20.00 90 -11.95 91 -20.00 92 -12.54
 ABUNDANCE CHANGE 93 -20.00 94 -20.00 95 -20.00 96 -20.00 97 -20.00 98 -20.00
 ABUNDANCE CHANGE 99 -20.00
ITERATIONS 1   PRINT 0 PUNCH 1
BEGIN
END
EOF

#The exit model is renamed
mv fort.7 result.mod

# if one wants fluxes

#ln -sf result.mod fort.3
#./atlas9mem_newodf.exe <<EOF
#SURFACE FLUX
#SURFACE INTENSITY 17 5.306000E-03  2.771200E-02  6.717900E-02
#1.223020E-01  1.910660E-01  2.709870E-01  3.591990E-01  4.524970E-01
#5.475050E-01  6.408070E-01  7.290040E-01  8.089350E-01  8.776990E-01
#9.328150E-01  9.722880E-01  9.947010E-01  1.000000E+00
#FREQUENCIES 1221 1 1221 LITTLE
#READ PUNCH
#OPACITY IFOP 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0
#ITERATIONS 1 PRINT 2 PUNCH 2
#BEGIN                    ITERATION  15 COMPLETED
#END
#EOF

#mv fort.7 result.flx

#Some garbage is removed
rm -f fort.*


